/* audit.c -- This file contains the audit system extensions
 *
 * Copyright 2005 Red Hat Inc., Durham, North Carolina.
 * All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Authors:
 *     Steve Grubb <sgrubb@redhat.com>
 */

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <unistd.h>
#include <libaudit.h>
#include "audit.h"

int audit_fd = -1;

/*
 * This function will log a message to the audit system using a predefined
 * message format. Parameter usage is as follows:
 *
 * op  -  operation. "adding user", "changing finger info", "deleting group"
 * result - 0 = "success"  or  1 = "failed"
 */
static void audit_logger(const char *op, int result) 
{
	char msg_buf[256]; /* Common buffer for messaging */
	const char *success;
	extern char *progname;

	if (!result)
		success = "success";
	else
		success = "failed";

	/* Add some audit info & log it.  */
	snprintf(msg_buf, sizeof(msg_buf),
		"%s: op=%s id=%u res=%s", progname, op, getuid(), success);
	audit_send_user_message(audit_fd, AUDIT_USYS_CONFIG, msg_buf);
	close(audit_fd);
}

static int audit_this = 0;
void auditable_event(int i)
{
	audit_this = i;
}

void audit_exit(int status)
{
	if (audit_this)
		audit_logger("changing system time", status);
	exit(status);
}

